SystemOrganization addCategory: #ConfigurationOfVivide!

Object subclass: #ConfigurationOfVivide
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfVivide'!

!ConfigurationOfVivide class methodsFor: 'development support' stamp: 'mt 8/20/2012 17:50:47.772'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfVivide class methodsFor: 'private' stamp: 'mt 8/20/2012 17:50:47.932'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfVivide class methodsFor: 'private' stamp: 'mt 8/20/2012 17:50:48.015'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfVivide class methodsFor: 'private' stamp: 'mt 8/20/2012 17:50:48.09'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfVivide class methodsFor: 'as yet unclassified' stamp: 'mt 7/19/2013 14:30:04.54'!
ensureRepositoryAccessFor: spec

	| privatePackages loginData |
	privatePackages := spec.
	loginData := Dictionary new.
		
	privatePackages keysAndValuesDo: [:packageName :location |
		| repository addDefault |
		addDefault := false.
		"Try to find the repository in the corresponding package."
		repository := (MCPackage named: packageName) workingCopy repositoryGroup in: [:group |
			group repositories
				detect: [:repo | repo description endsWith: location second]
				ifNone: []].
		"Try to find the repository in the default group."
		repository ifNil: [repository := (MCRepositoryGroup default repositories
			detect: [:repo | repo description endsWith: location second]
			ifNone: []) ifNotNil: [:r | addDefault := true. r]].
		
		"Create a new one if still not found."
		repository ifNil: [
			loginData at: location first ifAbsentPut: [
					(UIManager default request: 'User (', location first, ')')
						-> (UIManager default requestPassword: 'Password (', location first, ')')].
			repository := MCHttpRepository
					location: location first, location second
					user: (loginData at: location first) key
					password: (loginData at: location first) value.
			addDefault := true].
			
		addDefault ifTrue: [
			(MCPackage named: packageName) workingCopy repositoryGroup addRepository: repository]].! !

!ConfigurationOfVivide class methodsFor: 'metacello tool support' stamp: 'mt 8/20/2012 17:50:48.17'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfVivide class methodsFor: 'loading' stamp: 'mt 8/20/2012 17:50:48.249'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfVivide class methodsFor: 'loading' stamp: 'mt 8/20/2012 17:50:48.329'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfVivide class methodsFor: 'loading' stamp: 'mt 8/20/2012 17:50:48.407'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfVivide class methodsFor: 'loading' stamp: 'mt 8/20/2012 17:50:48.489'!
loadSnapshot
	"Load the latest snapshot which may be buggy but is not equivalent with the current head #development version."

	"self loadSnapshot"

	<apiDocumentation>
	^(self project version: #snapshot) load! !

!ConfigurationOfVivide class methodsFor: 'accessing' stamp: 'mt 7/18/2013 17:42:11.907'!
project

	^self new project! !

!ConfigurationOfVivide class methodsFor: 'development support' stamp: 'mt 8/20/2012 17:50:47.852'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfVivide methodsFor: 'baselines' stamp: 'mt 7/18/2013 18:33:34.372'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/vivide'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				loads: #(full)].

		spec project: 'OCompletion' with: [
			spec
				className: 'ConfigurationOfOCompletion';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].

		spec project: 'Sight-Coverage' with: [
			spec
				className: 'ConfigurationOfSightCoverage';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				preLoadDoIt: #preLoad].

		spec project: 'Sight-Callgraph' with: [
			spec
				className: 'ConfigurationOfSightCallgraph';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				preLoadDoIt: #preLoad].
			
		spec project: 'Sight-Tagging' with: [
			spec
				className: 'ConfigurationOfSightTagging';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				preLoadDoIt: #preLoad].

		spec package: 'VB-Regex' with: [
			spec repository: 'http://www.squeaksource.com/Regex'].
					
		spec package: 'Icons' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
		
		spec package: 'Fonts' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/swaprivate'].

		spec package: 'Vivide' with: [
			spec
				requires: #(Animations Signals 'VB-Regex' Widgets Icons Fonts OCompletion 'Sight-Coverage' 'Sight-Callgraph' 'Sight-Tagging');
				postLoadDoIt: #postLoad].

		spec
			group: 'default' with: #('Vivide')].! !

!ConfigurationOfVivide methodsFor: 'baselines' stamp: 'mt 7/19/2013 14:29:40.151'!
baseline110: spec
	<version: '1.1-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/vivide'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				loads: #(full)].
		
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					loads: #('Core')].

		spec project: 'OCompletion' with: [
			spec
				className: 'ConfigurationOfOCompletion';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].

		spec project: 'Sight-Coverage' with: [
			spec
				className: 'ConfigurationOfSightCoverage';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Sight-Callgraph' with: [
			spec
				className: 'ConfigurationOfSightCallgraph';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
			
		spec project: 'Sight-Tagging' with: [
			spec
				className: 'ConfigurationOfSightTagging';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec package: 'VB-Regex' with: [
			spec repository: 'http://www.squeaksource.com/Regex'].
					
		spec package: 'Icons' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
		
		spec package: 'Fonts' with: [
			spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/swaprivate';
				preLoadDoIt: #preLoad].

		spec package: 'Vivide' with: [
			spec
				requires: #(Animations Signals 'VB-Regex' Widgets Icons Fonts 'Refactoring-Core' OCompletion 'Sight-Coverage' 'Sight-Callgraph' 'Sight-Tagging');
				preLoadDoIt: #preLoad;  
				postLoadDoIt: #postLoad].

		spec
			group: 'default' with: #('Vivide')].! !

!ConfigurationOfVivide methodsFor: 'baselines' stamp: 'mt 7/19/2013 14:31:02.822'!
baseline120: spec
	<version: '1.2-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/vivide'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				loads: #(full)].
		
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					loads: #('Core')].

		spec project: 'OCompletion' with: [
			spec
				className: 'ConfigurationOfOCompletion';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].

		spec project: 'Sight-Coverage' with: [
			spec
				className: 'ConfigurationOfSightCoverage';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Sight-Callgraph' with: [
			spec
				className: 'ConfigurationOfSightCallgraph';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
			
		spec project: 'Sight-Tagging' with: [
			spec
				className: 'ConfigurationOfSightTagging';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec package: 'VB-Regex' with: [
			spec repository: 'http://www.squeaksource.com/Regex'].
		
		spec package: 'JSON' with: [
			spec repository: 'http://www.squeaksource.com/JSON'].
					
		spec package: 'Icons' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
		
		spec package: 'Fonts' with: [
			spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/swaprivate';
				preLoadDoIt: #preLoad].

		spec package: 'Vivide' with: [
			spec
				requires: #(Animations Signals 'VB-Regex' JSON Widgets Icons Fonts 'Refactoring-Core' OCompletion 'Sight-Coverage' 'Sight-Callgraph' 'Sight-Tagging');
				preLoadDoIt: #preLoad;
				postLoadDoIt: #postLoad].

		spec
			group: 'default' with: #('Vivide')].! !

!ConfigurationOfVivide methodsFor: 'baselines' stamp: 'mt 7/19/2013 14:31:25.157'!
baseline121: spec
	<version: '1.2.1-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/vivide'.
					
		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Animations' with: [
			spec
				className: 'ConfigurationOfAnimations';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository';
				loads: #(full)].
		
		spec project: 'Refactoring-Core' with: [
				spec
					className: 'ConfigurationOfRefactoringBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					loads: #('Core')].

		spec project: 'OCompletion' with: [
			spec
				className: 'ConfigurationOfOCompletion';
				repository: 'http://www.squeaksource.com/MetacelloRepository'].

		spec project: 'Sight-Coverage' with: [
			spec
				className: 'ConfigurationOfSightCoverage';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Sight-Callgraph' with: [
			spec
				className: 'ConfigurationOfSightCallgraph';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
			
		spec project: 'Sight-Tagging' with: [
			spec
				className: 'ConfigurationOfSightTagging';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec package: 'VB-Regex' with: [
			spec repository: 'http://www.squeaksource.com/Regex'].
		
		spec package: 'JSON' with: [
			spec repository: 'http://www.squeaksource.com/JSON'].
					
		spec package: 'Icons' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].
		
		spec package: 'Fonts' with: [
			spec
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/swaprivate';
				preLoadDoIt: #preLoad].

		spec project: 'PolySource' with: [
			spec
				className: 'ConfigurationOfCoExist';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec package: 'Vivide' with: [
			spec
				requires: #(Animations Signals 'VB-Regex' JSON Widgets Icons Fonts 'Refactoring-Core' OCompletion 'Sight-Coverage' 'Sight-Callgraph' 'Sight-Tagging');
				preLoadDoIt: #preLoad;
				postLoadDoIt: #postLoad].
				
		spec package: 'VividePolySource' with: [
			spec requires: #(Vivide PolySource)].

		spec
			group: 'default' with: #('core');
			group: 'core' with: #('Vivide');
			group: 'coexist' with: #('Vivide' 'VividePolySource')].! !

!ConfigurationOfVivide methodsFor: 'symbolic versions' stamp: 'mt 4/9/2013 10:12:48.088'!
development: spec 
	<symbolicVersion: #development>
	
	spec for: #'common' version: '2.0'.! !

!ConfigurationOfVivide methodsFor: 'pre-/postload' stamp: 'mt 4/3/2013 16:03:03.887'!
postLoad

	| normal list title small mono |
	ViTextStyler initialize.
	ViTextStylerForClass initialize.
	
	TextEditor allSubclassesDo: [:e | e initialize].
	
	UiFont installAllFonts.
	
	"Setup fonts."
	normal := StrikeFont familyName: #'Bitmap Segoe UI' pointSize: 10.
	list := StrikeFont familyName: #'Bitmap Segoe UI' pointSize: 9.
	small := StrikeFont familyName: #'Bitmap DejaVu Sans' pointSize: 7.
	mono := StrikeFont familyName: #'Bitmap Envy Code R' pointSize: 10.
	title := StrikeFont familyName: #'Bitmap Segoe UI Light' pointSize: 16.
	Preferences
		setSystemFontTo: normal;
		setListFontTo: list;
		setHaloLabelFontTo: mono;
		setMenuFontTo: list;
		setWindowTitleFontTo: title;
		setBalloonHelpFontTo: small;
		setCodeFontTo: mono;
		setButtonFontTo: list.
		
	Preferences
		addBooleanPreference: #useVivideDebugger
		categories: #('Vivide')
		default: true
		balloonHelp: 'Let''s you choose between default debugging and Vivide integration.'.
		
	Preferences
		addTextPreference: #feedbackServer
		categories: #('Vivide')
		default: 'http://www.hpi.uni-potsdam.de/hirschfeld/vivide-feedback/feedback'
		balloonHelp: 'Where are feedback reports posted to?'.
	
	(Smalltalk at: #ViToolSet ifAbsent: [])
		ifNotNil: [:ts | ToolSet default: ts].
	
	"First time setup."
	ActiveVivide ifNil: [VivideLight prepareSqueak; open].! !

!ConfigurationOfVivide methodsFor: 'pre-/postload' stamp: 'mt 7/19/2013 14:30:32.452'!
preLoad

	self class ensureRepositoryAccessFor: (Dictionary newFrom: {
		#'Fonts' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'swaprivate').
		#'Vivide' -> #('http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/' 'vivide')}).
	
	(Smalltalk includesKey: #ActiveVivide)
		ifFalse: [Smalltalk at: #ActiveVivide put: nil].! !

!ConfigurationOfVivide methodsFor: 'accessing' stamp: 'mt 8/20/2012 17:50:47.134'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfVivide methodsFor: 'symbolic versions' stamp: 'mt 4/9/2013 10:12:42.327'!
snapshot: spec
	<symbolicVersion: #snapshot>
	
	spec for: #'common' version: '1.2'.! !

!ConfigurationOfVivide methodsFor: 'symbolic versions' stamp: 'mt 4/9/2013 10:12:45.159'!
stable: spec
	<symbolicVersion: #stable>
	
	spec for: #'squeak4.x' version: '1.2'.! !

!ConfigurationOfVivide methodsFor: 'versions' stamp: 'mt 8/20/2012 19:18:27.022'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #snapshot.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: '1.0.5';
			project: 'Animations' with: '1.0.6';
			project: 'Widgets' with: '1.1-snapshot-120820';
			project: 'Sight-Coverage' with: '1.0.4';
			project: 'Sight-Callgraph' with: '1.0.2';
			project: 'Sight-Tagging' with: '0.1';
			project: 'OCompletion' with: '1.2.2'.
			
		spec
			package: 'VB-Regex' with: 'VB-Regex-damienpollet.17';
			package: 'Icons' with: 'Icons-mt.1';
			package: 'Fonts' with: 'Fonts-mt.6';
			package: 'Vivide' with: 'Vivide-mt.2'].! !

!ConfigurationOfVivide methodsFor: 'versions' stamp: 'mt 10/8/2012 11:53:49.233'!
version101: spec

	<version: '1.0.1' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #snapshot.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: '1.0.6';
			project: 'Animations' with: '1.0.7';
			project: 'Widgets' with: '1.1.1';
			project: 'Sight-Coverage' with: '1.0.4';
			project: 'Sight-Callgraph' with: '1.0.3';
			project: 'Sight-Tagging' with: '0.2';
			project: 'OCompletion' with: '1.2.2'.
			
		spec
			package: 'VB-Regex' with: 'VB-Regex-damienpollet.17';
			package: 'Icons' with: 'Icons-mt.2';
			package: 'Fonts' with: 'Fonts-mt.6';
			package: 'Vivide' with: 'Vivide-mt.58'].! !

!ConfigurationOfVivide methodsFor: 'versions' stamp: 'mt 2/22/2013 15:27:14.724'!
version110: spec

	<version: '1.1' imports: #('1.1-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		spec timestamp: '2/22/2013 15:00'.
		
		spec
			project: 'Signals' with: '1.0.6';
			project: 'Animations' with: '1.1.0';
			project: 'Widgets' with: '1.1.2';
			project: 'Sight-Coverage' with: '1.0.6';
			project: 'Sight-Callgraph' with: '1.0.4';
			project: 'Sight-Tagging' with: '0.2';
			project: 'Refactoring-Core' with: '2.0.1';
			project: 'OCompletion' with: '1.2.2'.
			
		spec
			package: 'VB-Regex' with: 'VB-Regex-damienpollet.17';
			package: 'Icons' with: 'Icons-mt.3';
			package: 'Fonts' with: 'Fonts-mt.6';
			package: 'Vivide' with: 'Vivide-mt.111'].! !

!ConfigurationOfVivide methodsFor: 'versions' stamp: 'mt 4/5/2013 15:13:40.67'!
version111: spec

	<version: '1.1.1' imports: #('1.1-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		spec timestamp: '4/5/2013 15:00'.
		
		spec
			project: 'Signals' with: '1.0.7';
			project: 'Animations' with: '1.1.0';
			project: 'Widgets' with: '1.1.3';
			project: 'Sight-Coverage' with: '1.0.7';
			project: 'Sight-Callgraph' with: '1.0.5';
			project: 'Sight-Tagging' with: '0.3';
			project: 'Refactoring-Core' with: '2.0.1';
			project: 'OCompletion' with: '1.2.2'.
			
		spec
			package: 'VB-Regex' with: 'VB-Regex-damienpollet.17';
			package: 'Icons' with: 'Icons-mt.3';
			package: 'Fonts' with: 'Fonts-mt.6';
			package: 'Vivide' with: 'Vivide-mt.142'].! !

!ConfigurationOfVivide methodsFor: 'versions' stamp: 'topa 4/9/2013 10:50:40.437'!
version120: spec
	<version: '1.2' imports: #('1.2-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'Marcel Taeumel'.
		spec timestamp: '4/9/2013 10:00'.
		
		spec
			project: 'Signals' with: '1.0.7.1';
			project: 'Animations' with: '1.1.0';
			project: 'Widgets' with: '1.1.3';
			project: 'Sight-Coverage' with: '1.0.7';
			project: 'Sight-Callgraph' with: '1.0.5';
			project: 'Sight-Tagging' with: '0.3';
			project: 'Refactoring-Core' with: '2.0.2';
			project: 'OCompletion' with: '1.4.2'.
			
		spec
			package: 'VB-Regex' with: 'VB-Regex-damienpollet.17';
			package: 'JSON' with: 'JSON-ul.35';
			package: 'Icons' with: 'Icons-mt.3';
			package: 'Fonts' with: 'Fonts-mt.6';
			package: 'Vivide' with: 'Vivide-mt.143'].! !

!ConfigurationOfVivide methodsFor: 'versions' stamp: 'mt 7/17/2013 16:24:04.276'!
version200: spec
	<version: '2.0' imports: #('1.2.1-baseline')>
	
	spec for: #common do: [
		spec blessing: #development.
		spec author: 'Marcel Taeumel'.
		
		spec
			project: 'Signals' with: #development;
			project: 'Animations' with: #development;
			project: 'Widgets' with: #development;
			project: 'Sight-Coverage' with: #development;
			project: 'Sight-Callgraph' with: #development;
			project: 'Sight-Tagging' with: #development;
			project: 'Refactoring-Core' with: '2.0.2';
			project: 'OCompletion' with: '1.4.2';
			project: 'PolySource' with: #development.
			
		spec
			package: 'VB-Regex' with: 'VB-Regex-damienpollet.17';
			package: 'JSON' with: 'JSON-ul.35'
"			package: 'Icons' with: 'Icons-mt.1';
			package: 'Fonts' with: 'Fonts-mt.6'
			package: 'Vivide' with: 'Vivide-mt.1'"].! !
